package safemoney

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Safemoney_lib.Qv_intfSource

Rational Representation

Wrapper type for Zarith Q rational type Q which serves as the underlying type for other currency types that are built based on rational values.

Apart from few helper conversion functions, this signature implement most of what is equivalent to the Num typeclass sensibly.

Sourcemodule type S = sig ... end